==> haskell-mime-mail-0.5.1-229-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mime-mail.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mime-mail
version:              0.5.1
visibility:           public
id:                   mime-mail-0.5.1-LYip0OXUWklJBfuYRji9hH
key:                  mime-mail-0.5.1-LYip0OXUWklJBfuYRji9hH
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Marek Suchánek <marek.suchanek@fit.cvut.cz>

author:               Michael Snoyman <michael@snoyman.com>
homepage:             http://github.com/snoyberg/mime-mail
synopsis:             Compose MIME email messages.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/mime-mail>.

category:             Email
abi:                  90ac8e9ef8a46d5e178f51bef366db6e
exposed:              True
exposed-modules:      Network.Mail.Mime
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mime-mail-0.5.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mime-mail-0.5.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mime-mail-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mime-mail
hs-libraries:         HSmime-mail-0.5.1-LYip0OXUWklJBfuYRji9hH
depends:
    base-4.17.2.1 base64-bytestring-1.2.1.0-AW9I0WOkr0IYZNZquGJUP
    blaze-builder-0.4.4.1-29vQnqICbd0LBEdca9xRON bytestring-0.11.5.3
    filepath-1.4.2.2 process-1.6.18.0
    random-1.2.1.3-U9X4N4HDf8JDMoZsBnozN text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-mime-mail/html/mime-mail.haddock
haddock-html:         /usr/share/doc/haskell-mime-mail/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mime-mail-0.5.1-230-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mime-mail.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mime-mail
version:              0.5.1
visibility:           public
id:                   mime-mail-0.5.1-KNEjvhetpj1AESrDN84vlt
key:                  mime-mail-0.5.1-KNEjvhetpj1AESrDN84vlt
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Marek Suchánek <marek.suchanek@fit.cvut.cz>

author:               Michael Snoyman <michael@snoyman.com>
homepage:             http://github.com/snoyberg/mime-mail
synopsis:             Compose MIME email messages.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/mime-mail>.

category:             Email
abi:                  fba1f01487c6113d5efd23fbd0326221
exposed:              True
exposed-modules:      Network.Mail.Mime
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mime-mail-0.5.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mime-mail-0.5.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mime-mail-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mime-mail
hs-libraries:         HSmime-mail-0.5.1-KNEjvhetpj1AESrDN84vlt
depends:
    base-4.17.2.1 base64-bytestring-1.2.1.0-7CU13IWnWdcDMU9nDc25iT
    blaze-builder-0.4.4.1-AKoSlOPVMSdAxdLMijM4A4 bytestring-0.11.5.3
    filepath-1.4.2.2 process-1.6.18.0
    random-1.2.1.3-53eBMyqCn4j5j5sTN6ACJa text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-mime-mail/html/mime-mail.haddock
haddock-html:         /usr/share/doc/haskell-mime-mail/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
